pub struct prof_final;Expand description
Use an atexit(3) function to dump final memory usage to a file named according to the pattern <prefix>.<pid>.<seq>.f.heap, where <prefix> is controlled by the opt.prof_prefix and prof.prefix options.
Note that atexit() may allocate memory during application initialization and then deadlock
internally when jemalloc in turn calls atexit(), so this option is not universally usable
(though the application can register its own atexit() function with equivalent
functionality).
This option is disabled by default.
Examples
use linera_jemalloc_ctl::profiling;
let prof_final = profiling::prof_final::read().unwrap();
println!("dump final memory usage to file: {}", prof_final);Implementations
Sourceimpl prof_final
impl prof_final
Sourcepub fn mib() -> Result<prof_final_mib>
pub fn mib() -> Result<prof_final_mib>
Returns Management Information Base (MIB)
This value can be used to access the key without doing string lookup.
Sourcepub fn name() -> &'static Name
pub fn name() -> &'static Name
Key crate::keys::Name.